import { createRouter, createWebHistory } from 'vue-router';
import { useAuthStore } from '../stores/auth.js'; // 确保路径正确

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      name: 'login',
      component: () => import('../views/Login.vue'),
    },
    {
      path: '/home',
      name: 'home',
      component: () => import('../views/Home.vue'),
      // meta: { requiresAuth: true }, 
    },
    {
      path: '/change-password',
      name: 'changePassword',
      component: () => import('../views/ChangePassword.vue')
    }
  ],
});

// 路由守卫
router.beforeEach((to, from, next) => {
  const authStore = useAuthStore(); // 获取登录状态

  if (to.meta.requiresAuth && !authStore.isAuthenticated) {
    // 如果目标路由需要认证且未登录，则跳转到登录页
    next({ name: 'login' });
  } else {
    // 否则允许进入
    next();
  }
});

export default router;
